SystemOrganization addCategory: #ConfigurationOfStateSpecs!

Object subclass: #ConfigurationOfStateSpecs
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfStateSpecs'!

!ConfigurationOfStateSpecs class methodsFor: 'development support' stamp: 'DenisKudryashov 1/20/2013 16:32'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfStateSpecs class methodsFor: 'private' stamp: 'DenisKudryashov 1/20/2013 16:32'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfStateSpecs class methodsFor: 'accessing' stamp: 'DenisKudyashov 4/5/2016 17:23'!
catalogContactInfo
	^ 'Written and maintained by Denis Kudriashov (http://dionisiydk.blogspot.com) and the community. Discussions on the Pharo mailing lists.'! !

!ConfigurationOfStateSpecs class methodsFor: 'accessing' stamp: 'DenisKudyashov 4/5/2016 17:22'!
catalogDescription
	^ 'StateSpecs is object state specification framework. It describes particular object states by first class specifications. For example there are SpecOfCollectionItem, SpecOfObjectClass and SpecOfObjectSuperclass. They can match and validate given objects. In case when object is not satisfied specification you will get failure result with detailed information about problem.

	spec matches: anObject.
	spec validate: anObject. "it returns validation result which can be success or particular failure"

To easily create specifications and validate objects by them StateSpecs provides two kind DSL: should expressions and "word" classes.
First allows you to write "assertions":

	1 should be: 2
	1 should equal: 10

And second allows you to instantiate specs by natural readable words:

	Kind of: Number
	Instance of: String
	Equal to: ''test'' '! !

!ConfigurationOfStateSpecs class methodsFor: 'accessing' stamp: 'DenisKudyashov 4/5/2016 17:24'!
catalogKeywords
	^ #(framework validation TDD BDD)! !

!ConfigurationOfStateSpecs class methodsFor: 'private' stamp: 'DenisKudryashov 1/20/2013 16:32'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfStateSpecs class methodsFor: 'private' stamp: 'DenisKudryashov 1/20/2013 16:32'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfStateSpecs class methodsFor: 'metacello tool support' stamp: 'DenisKudryashov 1/20/2013 16:32'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfStateSpecs class methodsFor: 'loading' stamp: 'DenisKudryashov 1/20/2013 16:32'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfStateSpecs class methodsFor: 'loading' stamp: 'DenisKudryashov 1/20/2013 16:32'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfStateSpecs class methodsFor: 'loading' stamp: 'DenisKudryashov 1/20/2013 16:32'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfStateSpecs class methodsFor: 'accessing' stamp: 'DenisKudryashov 1/20/2013 16:32'!
project

	^self new project! !

!ConfigurationOfStateSpecs class methodsFor: 'development support' stamp: 'DenisKudryashov 1/20/2013 16:32'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfStateSpecs methodsFor: 'baselines' stamp: 'DenisKudryashov 1/20/2013 17:41'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.smalltalkhub.com/mc/dionisiy/StateSpecs/main'.	
		spec 
			project: 'SMock' with: [
		     		spec
			      	className: 'ConfigurationOfSMock';
					repository: 'http://www.smalltalkhub.com/mc/dionisiy/SMock/main'];  
			package: 'StateSpecs';
			package: 'StateSpecsTests' with: [ spec requires: 'StateSpecs'; requires: 'SMock' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('StateSpecs');
			group: 'Tests' with: #('StateSpecsTests'). ].! !

!ConfigurationOfStateSpecs methodsFor: 'baselines' stamp: 'DenisKudryashov 3/3/2016 15:22'!
baseline20: spec 
	<version: '2.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.smalltalkhub.com/mc/dionisiy/StateSpecs/main'.	
		spec 
			package: 'StateSpecs-Specs';
			package: 'StateSpecs-DSL-ShouldExpressions' with: [ spec requires: #('StateSpecs-Specs') ];
			package: 'StateSpecs-DSL-ClassWords' with: [ spec requires: #('StateSpecs-Specs') ];
			package: 'StateSpecs-DSL-PragmaBasedShouldExpressions' with: [ spec requires: #('StateSpecs-Specs' 'StateSpecs-DSL-ShouldExpressions')];
			
			package: 'StateSpecsTests-Specs' with: [ spec requires: 'StateSpecs-Specs' ];
			package: 'StateSpecsTests-DSL-ShouldExpressions' with: [ spec requires: 'StateSpecs-DSL-ShouldExpressions' ];
			package: 'StateSpecsTests-DSL-ClassWords' with: [ spec requires: 'StateSpecs-DSL-ClassWords' ];
			package: 'StateSpecsTests-DSL-PragmaBasedShouldExpressions' with: [ spec requires: 'StateSpecs-DSL-PragmaBasedShouldExpressions' ].

		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('StateSpecs-Specs' 'StateSpecs-DSL-ShouldExpressions' 'StateSpecs-DSL-ClassWords');
			group: 'Tests' with: #('StateSpecsTests-Specs' 'StateSpecsTests-DSL-ShouldExpressions' 'StateSpecsTests-DSL-ClassWords');
			group: 'PragmaBasedShouldExpressions' with: #('StateSpecs-DSL-PragmaBasedShouldExpressions' 'StateSpecsTests-DSL-PragmaBasedShouldExpressions')].! !

!ConfigurationOfStateSpecs methodsFor: 'baselines' stamp: 'DenisKudyashov 4/5/2016 17:14'!
baseline21: spec 
	<version: '2.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.smalltalkhub.com/mc/dionisiy/StateSpecs/main'.	
		spec 
			package: 'StateSpecs-Specs';
			package: 'StateSpecs-DSL-ShouldExpressions' with: [ spec requires: #('StateSpecs-Specs') ];
			package: 'StateSpecs-DSL-ClassWords' with: [ spec requires: #('StateSpecs-Specs') ];
			package: 'StateSpecsHelp' with: [
				spec requires: #('StateSpecs-DSL-ShouldExpressions' 'StateSpecs-DSL-ClassWords')];
			
			package: 'StateSpecsTests-Specs' with: [ spec requires: 'StateSpecs-Specs' ];
			package: 'StateSpecsTests-DSL-ShouldExpressions' with: [ spec requires: 'StateSpecs-DSL-ShouldExpressions' ];
			package: 'StateSpecsTests-DSL-ClassWords' with: [ spec requires: 'StateSpecs-DSL-ClassWords' ].
		
		spec
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('StateSpecs-Specs' 'StateSpecs-DSL-ShouldExpressions' 'StateSpecs-DSL-ClassWords');
			group: 'Tests' with: #('StateSpecsTests-Specs' 'StateSpecsTests-DSL-ShouldExpressions' 'StateSpecsTests-DSL-ClassWords' 'StateSpecsHelp').
	]! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudyashov 4/5/2016 17:25'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #'common' version: '2.1-baseline'! !

!ConfigurationOfStateSpecs methodsFor: 'accessing' stamp: 'DenisKudryashov 1/20/2013 16:32'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudyashov 4/5/2016 17:25'!
stable: spec
	<symbolicVersion: #stable>
	spec for: #common version: '2.1'! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudryashov 1/20/2013 17:42'!
version10: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'StateSpecs is a  object state specifications framework with SSpec functionality'.
		spec 
			package: 'StateSpecs' with: 'StateSpecs-DenisKudryashov.7';
			package: 'StateSpecsTests' with: 'StateSpecsTests-DenisKudryashov.3';
			project: 'SMock' with: '1.0'].! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudryashov 3/28/2013 23:27'!
version11: spec 
	<version: '1.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'StateSpecs is a  object state specifications framework with SSpec functionality'.
		spec 
			package: 'StateSpecs' with: 'StateSpecs-DenisKudryashov.12';
			package: 'StateSpecsTests' with: 'StateSpecsTests-DenisKudryashov.6';
			project: 'SMock' with: '1.0'].! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudryashov 6/8/2015 00:19'!
version12: spec 
	<version: '1.2' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'StateSpecs is a  object state specifications framework with SSpec functionality'.
		spec 
			package: 'StateSpecs' with: 'StateSpecs-DenisKudryashov.12';
			package: 'StateSpecsTests' with: 'StateSpecsTests-DenisKudryashov.7';
			project: 'SMock' with: '1.0'].! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudryashov 3/23/2016 12:08'!
version20: spec 
	<version: '2.0' imports: #('2.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'StateSpecs is a  object state specifications framework with SSpec functionality'.
		spec 
			package: 'StateSpecs-Specs' with: 'StateSpecs-Specs-DenisKudryashov.11';
			package: 'StateSpecs-DSL-ShouldExpressions' with: 'StateSpecs-DSL-ShouldExpressions-DenisKudryashov.7';
			package: 'StateSpecs-DSL-ClassWords' with: 'StateSpecs-DSL-ClassWords-DenisKudryashov.3';
			package: 'StateSpecsTests-Specs' with: 'StateSpecsTests-Specs-DenisKudryashov.8';
			package: 'StateSpecsTests-DSL-ShouldExpressions' with: 'StateSpecsTests-DSL-ShouldExpressions-DenisKudryashov.6';
			package: 'StateSpecsTests-DSL-ClassWords' with: 'StateSpecsTests-DSL-ClassWords-DenisKudryashov.2';
			package: 'StateSpecs-DSL-PragmaBasedShouldExpressions' with: 'StateSpecsTests-DSL-PragmaBasedShouldExpressions-DenisKudryashov.4';
			package: 'StateSpecsTests-DSL-PragmaBasedShouldExpressions' with: 'StateSpecsTests-DSL-PragmaBasedShouldExpressions-DenisKudryashov.3'
].! !

!ConfigurationOfStateSpecs methodsFor: 'versions' stamp: 'DenisKudryashov 4/5/2016 17:31'!
version21: spec 
	<version: '2.1' imports: #('2.1-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec description: 'StateSpecs is a object state specifications framework with SSpec functionality'.
		spec 
			package: 'StateSpecs-Specs' with: 'StateSpecs-Specs-DenisKudryashov.14';
			package: 'StateSpecs-DSL-ShouldExpressions' with: 'StateSpecs-DSL-ShouldExpressions-DenisKudryashov.7';
			package: 'StateSpecs-DSL-ClassWords' with: 'StateSpecs-DSL-ClassWords-DenisKudryashov.3';
			package: 'StateSpecsTests-Specs' with: 'StateSpecsTests-Specs-DenisKudryashov.8';
			package: 'StateSpecsTests-DSL-ShouldExpressions' with: 'StateSpecsTests-DSL-ShouldExpressions-DenisKudryashov.6';
			package: 'StateSpecsTests-DSL-ClassWords' with: 'StateSpecsTests-DSL-ClassWords-DenisKudryashov.2';
			package: 'StateSpecsHelp' with: 'StateSpecsHelp-DenisKudryashov.3'
].! !
